import logging
from logging import getLogger, StreamHandler, Logger
from uuid import uuid4

def get_logger() -> Logger:
    logger = getLogger(__name__)
    if not logger.handlers:
        logger.setLevel(logging.INFO)
        formatter = logging.Formatter(
            fmt='[%(asctime)s][ERIC][%(levelname)s]%(message)s', datefmt='%Y-%m-%d %H:%M:%S'
        )
        handler = StreamHandler()
        handler.setFormatter(formatter)
        logger.addHandler(handler)

    return logger

def generate_uuid() -> str:
    return str(uuid4())



from dataclasses import dataclass

from eric_sse.listener import MessageQueueListener
from eric_sse.queues import Queue


@dataclass
class Connection:
    """
    A connection is just a listener and its related message queue

    :param ~eric_sse.listener.MessageQueueListener listener:
    :param ~eric_sse.queues.Queue queue:
    """
    listener: MessageQueueListener
    queue: Queue
